.. _components:

Components
##########

The different Py-ABAC components corresponding to those in the access control architecture are described in this section.
Using these components you can implement fine-grained access control for your protected resources.

.. _components_policy:

.. include:: policy.rst

.. _components_access_request:

.. include:: request.rst

.. _components_pdp:

.. include:: pdp.rst

.. _components_storage:

.. include:: storage.rst

.. _components_attribute_provider:

.. include:: provider.rst

.. _components_evaluation_context:

.. include:: context.rst
